==========================
Rejected Companion Library
==========================

This library contains a number of utility and helper classes that were
embedded in consumers that I have written recently.  They add useful
functionality on top of `rejected`_.

+---------------+-------------------------------------------------+
| |GitHub|      | https://github.com/dave-shawley/vetoes          |
+---------------+-------------------------------------------------+
| |PyPI|        | https://pypi.org/project/vetoes/                |
+---------------+-------------------------------------------------+
| |Docs|        | https://pythonhosted.org/vetoes/                |
+---------------+-------------------------------------------------+
| |Coveralls|   | https://coveralls.io/github/dave-shawley/vetoes |
+---------------+-------------------------------------------------+
| |Travis|      | https://travis-ci.org/dave-shawley/vetoes       |
+---------------+-------------------------------------------------+

.. _rejected: https://rejected.readthedocs.io/
.. |Coveralls| image:: https://img.shields.io/coveralls/dave-shawley/vetoes.svg
   :target: https://coveralls.io/github/dave-shawley/vetoes
.. |GitHub| image:: https://img.shields.io/github/release/daves-shawley/vetoes.svg
   :target: https://github.com/dave-shawley/vetoes
.. |PyPI| image:: https://img.shields.io/pypi/v/vetoes.svg
   :target: https://pypi.org/project/vetoes
.. |Docs| image:: https://img.shields.io/badge/docs-pythonhosted-green.svg
   :target: https://pythonhosted.com/vetoes/
.. |Travis| image:: https://img.shields.io/travis/dave-shawley/vetoes.svg
   :target: https://travis-ci.org/dave-shawley/vetoes
